ai-refactor-cli library facade.
Exposes the scanner API so it can be used from benchmarks and integration tests without going through the CLI binary.
ai-refactor-cli library facade.
Exposes the scanner API so it can be used from benchmarks and integration tests without going through the CLI binary.