Module scanner

Module scanner 

Filesystem walker that applies rules to files.

v0.2.0: Python files use tree-sitter AST detection (no more regex false positives from comments and string literals). TypeScript files continue to use the v0.1.0 regex path until tree-sitter-typescript ships in v0.3.0.

Structs

Finding

Functions

scan_path
Recursively scan path, optionally restricted to a single rule id.